summaryrefslogtreecommitdiff
path: root/libs
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2009-03-11 19:28:46 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2009-03-11 19:28:46 +0000
commit76186b105d82f7e4bc5693739c65aa71ccaff709 (patch)
tree5dbdfe8ab496d79bf95d721e9c4448a60e4ff008 /libs
parente4f80e68846c88fe7fe60243a0d6a8dd010990b5 (diff)
default click i/o setup is dual mono
git-svn-id: svn://localhost/ardour2/branches/2.0-ongoing@4795 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs')
-rw-r--r--libs/ardour/session.cc22
1 files changed, 12 insertions, 10 deletions
diff --git a/libs/ardour/session.cc b/libs/ardour/session.cc
index 7ca817147e..e0221b53cc 100644
--- a/libs/ardour/session.cc
+++ b/libs/ardour/session.cc
@@ -677,8 +677,6 @@ Session::set_worst_io_latencies ()
void
Session::when_engine_running ()
{
- string first_physical_output;
-
/* we don't want to run execute this again */
BootMessage (_("Set block size and sample rate"));
@@ -725,17 +723,21 @@ Session::when_engine_running ()
} else {
- /* default state for Click */
-
- first_physical_output = _engine.get_nth_physical_audio_output (0);
+ /* default state for Click: dual-mono to first 2 physical outputs */
- if (first_physical_output.length()) {
- if (_click_io->add_output_port (first_physical_output, this)) {
- // relax, even though its an error
- } else {
- _clicking = Config->get_clicking ();
+ for (int physport = 0; physport < 2; ++physport) {
+ string physical_output = _engine.get_nth_physical_audio_output (physport);
+
+ if (physical_output.length()) {
+ if (_click_io->add_output_port (physical_output, this)) {
+ // relax, even though its an error
+ }
}
}
+
+ if (_click_io->n_outputs() > 0) {
+ _clicking = Config->get_clicking ();
+ }
}
}